@@ -5,6 +5,7 @@ pub struct CliOptions {
     pub long_format: bool,
     pub dirs_only: bool,
     pub directory: String,
+    pub sorted: bool,
 }
 
 /// Constructs a CliOptions struct from a Vec<String> of arguments
@@ -16,7 +17,7 @@ pub fn build_options_from_args(args: Vec<String>) -> CliOptions {
     let mut options = CliOptions::new();
     let mut dir_set = false;
 
-    args.iter().for_each(|arg|
+    args.iter().for_each(|arg| {
         if arg.starts_with('-') {
             if arg == "-a" {
                 options.all = true;
@@ -24,6 +25,8 @@ pub fn build_options_from_args(args: Vec<String>) -> CliOptions {
                 options.long_format = true;
             } else if arg == "-d" {
                 options.dirs_only = true;
+            } else if arg == "-s" {
+                options.sorted = true;
             } else {
                 panic!("neols: Error - Unknown argument: {}", arg);
             }
@@ -35,7 +38,7 @@ pub fn build_options_from_args(args: Vec<String>) -> CliOptions {
                 panic!("neols: Error - Unknown argument: {}", arg);
             }
         }
-    );
+    });
 
     options
 }
@@ -61,6 +64,7 @@ impl CliOptions {
             long_format: false,
             dirs_only: false,
             directory: ".".to_string(),
+            sorted: false,
         }
     }
 }
